@@ -60,11 +60,12 @@ def status(type, message=None):
 
   # if not running in a ScraperWiki platform box, silently do nothing
   if not _in_box():
-    return
+    return "Not in box"
 
   # send status update to the box
   r = requests.post("https://scraperwiki.com/api/status", data={'type':type, 'message':message})
   r.raise_for_status()
+  return r.content
 
 
 
